--- a/pcs/settings.py.debian
+++ b/pcs/settings.py.debian
@@ -4,10 +4,10 @@ ccs_binaries = "/usr/sbin/"
 corosync_conf_file = "/etc/corosync/corosync.conf"
 cluster_conf_file = "/etc/cluster/cluster.conf"
 fence_agent_binaries = "/usr/sbin/"
-pengine_binary = "/usr/lib/DEB_HOST_MULTIARCH/pacemaker/pengine"
-crmd_binary = "/usr/lib/DEB_HOST_MULTIARCH/pacemaker/crmd"
-cib_binary = "/usr/lib/DEB_HOST_MULTIARCH/pacemaker/cib"
-stonithd_binary = "/usr/lib/DEB_HOST_MULTIARCH/pacemaker/stonithd"
+pengine_binary = "/usr/lib/pacemaker/pengine"
+crmd_binary = "/usr/lib/pacemaker/crmd"
+cib_binary = "/usr/lib/pacemaker/cib"
+stonithd_binary = "/usr/lib/pacemaker/stonithd"
 pcs_version = "0.9.149"
 crm_report = pacemaker_binaries + "crm_report"
 crm_verify = pacemaker_binaries + "crm_verify"
--- a/pcsd/settings.rb.debian
+++ b/pcsd/settings.rb.debian
@@ -9,8 +9,8 @@ OCF_ROOT = "/usr/lib/ocf"
 HEARTBEAT_AGENTS_DIR = "/usr/lib/ocf/resource.d/heartbeat/"
 PACEMAKER_AGENTS_DIR = "/usr/lib/ocf/resource.d/pacemaker/"
 NAGIOS_METADATA_DIR = '/usr/share/pacemaker/nagios/plugins-metadata/'
-PENGINE = "/usr/lib/DEB_HOST_MULTIARCH/pacemaker/pengine"
-CIB_BINARY = '/usr/lib/DEB_HOST_MULTIARCH/pacemaker/cib'
+PENGINE = "/usr/lib/pacemaker/pengine"
+CIB_BINARY = '/usr/lib/pacemaker/cib'
 CRM_MON = "/usr/sbin/crm_mon"
 CRM_NODE = "/usr/sbin/crm_node"
 CRM_ATTRIBUTE = "/usr/sbin/crm_attribute"
